@@ -52,10 +52,9 @@ QString JournalsPlug::title() const
     return title;
 }
 
-void JournalsPlug::onActivated()
+void JournalsPlug::onChange()
 {
-    if (this->isOutdated())
-        reload();
+    reload();
 }
 
 void JournalsPlug::reload()
