@@ -6,16 +6,12 @@
 
 #include <CRecurrence.h>
 
-namespace Ui {
-    class RecurrencePickDialog;
-}
-
 class RecurrencePickDialog : public RotatingDialog
 {
     Q_OBJECT
 
 public:
-    RecurrencePickDialog(QWidget *parent, CRecurrence *recurrence);
+    RecurrencePickDialog(QWidget *parent, CRecurrence *&recurrence);
     ~RecurrencePickDialog();
 
 public slots:
@@ -24,19 +20,24 @@ public slots:
 private:
     Ui::RecurrencePickDialog *ui;
 
-    CRecurrence *recurrence;
+    CRecurrence *&recurrence;
+    vector<string> rules;
+    unsigned int currentRule;
 
     static QString freqToStr(int frequency);
     static int freqFromStr(QString frequency);
     static int recurrenceType(CRecurrence *recurrence);
 
-    void parseRule(QString rule);
+    void clear();
+    void parseRule(const string &rule);
+    QString buildRule();
 
 private slots:
     void onFrequencyChanged(int index);
     void onLimitTypeChanged(int index);
 
-    void autoResize();
+    void exportRule();
+    void importRule();
 };
 
 #endif // RECURRENCEPICKDIALOG_H
