@@ -2,17 +2,16 @@
 
 #include <QFileDialog>
 #include <QMessageBox>
+#include <QMaemo5InformationBox>
 
+#include <CalendarErrors.h>
 #include <CMulticalendar.h>
 #include <CCalendar.h>
 
-#include "CWrapper.h"
-
 #include "ColorPickSelector.h"
 
 #include "ChangeManager.h"
-
-#include <QDebug>
+#include "CWrapper.h"
 
 CalendarEditDialog::CalendarEditDialog(int calendarId, QWidget *parent) :
     RotatingDialog(parent),
@@ -22,28 +21,19 @@ CalendarEditDialog::CalendarEditDialog(int calendarId, QWidget *parent) :
 
     this->setAttribute(Qt::WA_DeleteOnClose);
 
-    // Set up action buttons
-    QPushButton *exportButton = new QPushButton(tr("Export"));
-    QPushButton *deleteButton = new QPushButton(tr("Delete"));
-    QPushButton *saveButton   = new QPushButton(tr("Save"));
-    ui->buttonBox->addButton(exportButton, QDialogButtonBox::ActionRole);
-    ui->buttonBox->addButton(deleteButton, QDialogButtonBox::ActionRole);
-    ui->buttonBox->addButton(saveButton,   QDialogButtonBox::ActionRole);
-    connect(exportButton, SIGNAL(clicked()), this, SLOT(exportCalendar()));
-    connect(deleteButton, SIGNAL(clicked()), this, SLOT(deleteCalendar()));
-    connect(saveButton,   SIGNAL(clicked()), this, SLOT(saveCalendar()));
-
     typeGroup = new QButtonGroup(this);
     typeGroup->addButton(ui->localTypeButton, LOCAL_CALENDAR);
     typeGroup->addButton(ui->birthdayTypeButton, BIRTHDAY_CALENDAR);
     ui->localTypeButton->setChecked(true);
 
+    ui->typeWidget->hide();
+
     // Set up the color button
     ColorPickSelector *cps = new ColorPickSelector();
     ui->colorButton->setPickSelector(cps);
 
     if (calendarId) {
-        // Edit calendar
+        // Load an existing calendar
         int error;
         calendar = CMulticalendar::MCInstance()->getCalendarById(calendarId, error);
         ui->typeInfo->setText(CWrapper::calendarType(calendar->getCalendarType()));
@@ -52,15 +42,19 @@ CalendarEditDialog::CalendarEditDialog(int calendarId, QWidget *parent) :
 
         cps->setColor(calendar->getCalendarColor());
 
-        qDebug() << calendar->toString().c_str();
+        // Set up action buttons
+        QPushButton *exportButton = new QPushButton(tr("Export"));
+        QPushButton *deleteButton = new QPushButton(tr("Delete"));
+        ui->buttonBox->addButton(exportButton, QDialogButtonBox::ActionRole);
+        ui->buttonBox->addButton(deleteButton, QDialogButtonBox::ActionRole);
+        connect(exportButton, SIGNAL(clicked()), this, SLOT(exportCalendar()));
+        connect(deleteButton, SIGNAL(clicked()), this, SLOT(deleteCalendar()));
 
-        ui->typeWidget->hide();
+        this->setWindowTitle(tr("Edit calendar"));
     } else {
-        // New calendar
-        calendar = NULL;
+        // Create a new calendar
+        calendar = new CCalendar();
         ui->visibleBox->setChecked(true);
-        exportButton->setEnabled(false);
-        deleteButton->setEnabled(false);
 
         // Count color occurences
         CMulticalendar *mc = CMulticalendar::MCInstance();
@@ -78,10 +72,16 @@ CalendarEditDialog::CalendarEditDialog(int calendarId, QWidget *parent) :
 
         cps->setColor(rarestColor);
 
-        /*ui->typeInfo->hide();*/
-        ui->typeWidget->hide();
+        ui->typeInfo->hide();
+
+        this->setWindowTitle(tr("New calendar"));
     }
 
+    // Set up the save button
+    QPushButton *saveButton = new QPushButton(tr("Save"));
+    ui->buttonBox->addButton(saveButton, QDialogButtonBox::ActionRole);
+    connect(saveButton, SIGNAL(clicked()), this, SLOT(saveCalendar()));
+
     this->setFeatures(ui->dialogLayout, ui->buttonBox);
 }
 
@@ -92,32 +92,42 @@ CalendarEditDialog::~CalendarEditDialog()
     delete ui;
 }
 
+int CalendarEditDialog::calendarId()
+{
+    return calendar->getCalendarId();
+}
+
+void CalendarEditDialog::setCalendarName(QString name)
+{
+    ui->nameEdit->setText(name);
+}
+
 // Create a new calendar or save changes to the existing one
 void CalendarEditDialog::saveCalendar()
 {
-    const bool create = !calendar;
-
-    if (create) {
-        calendar = new CCalendar();
-        // TODO: Make it possible to add the birthday calendar
-        /*if (typeGroup->checkedId() == BIRTHDAY_CALENDAR)
-            calendar->setCalendarType(BIRTHDAY_CALENDAR);*/
-    }
+    // TODO: Make it possible to add the birthday calendar
+    /*if (typeGroup->checkedId() == BIRTHDAY_CALENDAR)
+        calendar->setCalendarType(BIRTHDAY_CALENDAR);*/
 
     calendar->setCalendarName(ui->nameEdit->text().toUtf8().data());
     calendar->setCalendarColor((CalendarColour) static_cast<ColorPickSelector*>(ui->colorButton->pickSelector())->currentColor());
     calendar->setCalendarShown(ui->visibleBox->isChecked());
 
     int error;
-    if (create) {
-        CMulticalendar::MCInstance()->addCalendar(calendar, error);
-    } else {
+
+    if (calendar->getCalendarId() > 0) {
         CMulticalendar::MCInstance()->modifyCalendar(calendar, error);
+    } else {
+        CMulticalendar::MCInstance()->addCalendar(calendar, error);
     }
 
     ChangeManager::bump();
 
-    this->accept();
+    if (error == CALENDAR_OPERATION_SUCCESSFUL) {
+        this->accept();
+    } else {
+        QMaemo5InformationBox::information(this->parentWidget(), tr("Error occurred"));
+    }
 }
 
 // Show file saving dialog and export the calendar
